summaryrefslogtreecommitdiff
path: root/src/mongo/db/matcher/expression_array.h
diff options
context:
space:
mode:
authorEliot Horowitz <eliot@10gen.com>2013-04-29 17:46:24 -0400
committerEliot Horowitz <eliot@10gen.com>2013-04-29 17:46:24 -0400
commitdab9c1a25454c06a5dd94eb093a0d2a64bf9d9d3 (patch)
tree238d3a9b627ae084e27519aa74e2c42114631f79 /src/mongo/db/matcher/expression_array.h
parent1bba08742e836118267f4162a36cbbc222b445fd (diff)
downloadmongo-dab9c1a25454c06a5dd94eb093a0d2a64bf9d9d3.tar.gz
SERVER-6400 rename *Expression* to *MatchExpression* to avoid conflict
Diffstat (limited to 'src/mongo/db/matcher/expression_array.h')
-rw-r--r--src/mongo/db/matcher/expression_array.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/src/mongo/db/matcher/expression_array.h b/src/mongo/db/matcher/expression_array.h
index 07856284d9a..1d467a16ad1 100644
--- a/src/mongo/db/matcher/expression_array.h
+++ b/src/mongo/db/matcher/expression_array.h
@@ -28,7 +28,7 @@
namespace mongo {
/**
* this SHOULD extend from ArrayMatchingExpression
* the only reason it can't is
> db.foo.insert( { x : 5 } )
@@ -40,7 +40,7 @@ namespace mongo {
* the { x : 5} doc should NOT match
*
*/
- class AllExpression : public Expression {
+ class AllMatchExpression : public MatchExpression {
public:
Status init( const StringData& path );
ArrayFilterEntries* getArrayFilterEntries() { return &_arrayEntries; }
@@ -58,9 +58,9 @@ namespace mongo {
};
- class ArrayMatchingExpression : public Expression {
+ class ArrayMatchingMatchExpression : public MatchExpression {
public:
- virtual ~ArrayMatchingExpression(){}
+ virtual ~ArrayMatchingMatchExpression(){}
virtual bool matches( const BSONObj& doc, MatchDetails* details ) const;
@@ -76,24 +76,24 @@ namespace mongo {
};
- class ElemMatchObjectExpression : public ArrayMatchingExpression {
+ class ElemMatchObjectMatchExpression : public ArrayMatchingMatchExpression {
public:
- Status init( const StringData& path, const Expression* sub );
+ Status init( const StringData& path, const MatchExpression* sub );
bool matchesArray( const BSONObj& anArray, MatchDetails* details ) const;
virtual void debugString( StringBuilder& debug, int level ) const;
private:
- boost::scoped_ptr<const Expression> _sub;
+ boost::scoped_ptr<const MatchExpression> _sub;
};
- class ElemMatchValueExpression : public ArrayMatchingExpression {
+ class ElemMatchValueMatchExpression : public ArrayMatchingMatchExpression {
public:
- virtual ~ElemMatchValueExpression();
+ virtual ~ElemMatchValueMatchExpression();
Status init( const StringData& path );
- Status init( const StringData& path, const Expression* sub );
- void add( const Expression* sub );
+ Status init( const StringData& path, const MatchExpression* sub );
+ void add( const MatchExpression* sub );
bool matchesArray( const BSONObj& anArray, MatchDetails* details ) const;
@@ -101,19 +101,19 @@ namespace mongo {
private:
bool _arrayElementMatchesAll( const BSONElement& e ) const;
- std::vector< const Expression* > _subs;
+ std::vector< const MatchExpression* > _subs;
};
/**
* i'm suprised this isn't a regular AllExpression
*/
- class AllElemMatchOp : public Expression {
+ class AllElemMatchOp : public MatchExpression {
public:
virtual ~AllElemMatchOp();
Status init( const StringData& path );
- void add( const ArrayMatchingExpression* expr );
+ void add( const ArrayMatchingMatchExpression* expr );
virtual bool matches( const BSONObj& doc, MatchDetails* details ) const;
@@ -127,10 +127,10 @@ namespace mongo {
bool _allMatch( const BSONObj& anArray ) const;
StringData _path;
- std::vector< const ArrayMatchingExpression* > _list;
+ std::vector< const ArrayMatchingMatchExpression* > _list;
};
- class SizeExpression : public ArrayMatchingExpression {
+ class SizeMatchExpression : public ArrayMatchingMatchExpression {
public:
Status init( const StringData& path, int size );
@@ -28,7 +28,7 @@
namespace mongo {
/**
- * this SHOULD extend from ArrayMatchingExpression
+ * this SHOULD extend from ArrayMatchingMatchExpression
* the only reason it can't is
> db.foo.insert( { x : 5 } )
@@ -101,19 +101,19 @@ namespace mongo {
};
/**
- * i'm suprised this isn't a regular AllExpression
+ * i'm suprised this isn't a regular AllMatchExpression
*/